Data documentation compiled by Great Expectations

### Expectation Suite Overview

#### Info

Full Data Asset Identifier | data__dir/default/bob-ross
Data Asset Type | Dataset
Expectation Suite Name | BasicDatasetProfiler
Great Expectations Version | v0.7.8__develop

#### Table-Level Expectations

- Must have more than 0 rows.
- This table should have a list of columns in a specific order, but that order is not specified.

#### Notes

This Expectation suite currently contains 417 total Expectations across 69 columns.

To add additional notes, edit the `meta.notes.content` field in the appropriate Expectation json file.

### APPLE_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### AURORA_BOREALIS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BARN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BEACH

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BOAT

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BRIDGE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BUILDING

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### BUSHES

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CABIN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CACTUS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CIRCLE_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CIRRUS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CLIFF

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CLOUDS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CONIFER

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### CUMULUS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### DECIDUOUS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### DIANE_ANDRE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### DOCK

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### DOUBLE_OVAL_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### EPISODE

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- values must not match this regular expression: ^\s+|\s+$.
- values must be unique.

### FARM

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FENCE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FIRE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FLORIDA_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FLOWERS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FOG

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### FRAMED

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### GRASS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### GUEST

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### HALF_CIRCLE_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### HALF_OVAL_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### HILLS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### LAKE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### LAKES

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### LIGHTHOUSE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### MILL

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### MOON

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### MOUNTAIN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### MOUNTAINS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### NIGHT

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### OCEAN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### OVAL_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### PALM_TREES

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### PATH

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### PERSON

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### PORTRAIT

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### RECTANGLE_3D_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### RECTANGULAR_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### RIVER

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### ROCKS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### SEASHELL_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### SNOW

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### SNOWY_MOUNTAIN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### SPLIT_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### STEVE_ROSS

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### STRUCTURE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### SUN

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### TITLE

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- values must not match this regular expression: ^\s+|\s+$.

### TOMB_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### TREE

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### TREES

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### TRIPLE_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WATERFALL

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WAVES

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WINDMILL

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WINDOW_FRAME

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WINTER

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

### WOOD_FRAMED

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must belong to this set: [ ].
- distinct values must belong to a set, but that set is not specified.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.